Index: branches/new_class_id/src/lib/graphics/importer/resource_texture.cc
===================================================================
--- branches/new_class_id/src/lib/graphics/importer/resource_texture.cc	(revision 9787)
+++ branches/new_class_id/src/lib/graphics/importer/resource_texture.cc	(revision 9788)
@@ -6,7 +6,7 @@
 
 ResourceTexture::ResourceTexture(const std::string& imageName, GLenum target)
-    : Resource(&ResourceTexture::type)
+    : NewResource(&ResourceTexture::type)
 {
-  Resource::Pointer* ptr = this->acquireResource(imageName + ',' + "TEST");
+  NewResource::Pointer* ptr = this->acquireResource(imageName + ',' + "TEST");
 
   if (ptr)
@@ -18,12 +18,12 @@
   {
     printf("NOT FOUNT TEXTURE: %s\n", imageName.c_str());
-    std::string fileName = this->Resource::locateFile(imageName);
+    std::string fileName = this->NewResource::locateFile(imageName);
     this->Texture::loadImage(fileName, target);
-    this->Resource::addResource(new ResourceTexture::TextureResourcePointer(imageName + ',' + "TEST", KeepLevel(), this->Texture::dataPointer()));
+    this->NewResource::addResource(new ResourceTexture::TextureResourcePointer(imageName + ',' + "TEST", KeepLevel(), this->Texture::dataPointer()));
   }
 }
 
 
-Resource::Type ResourceTexture::type(Texture::staticClassID());
+NewResource::Type ResourceTexture::type(Texture::staticClassID());
 
 
@@ -31,6 +31,6 @@
 
 
-ResourceTexture::TextureResourcePointer::TextureResourcePointer(const std::string& loadString, const Resource::KeepLevel& keepLevel, const TextureData::Pointer& data)
-    : Resource::Pointer(loadString, keepLevel) , pointer(data)
+ResourceTexture::TextureResourcePointer::TextureResourcePointer(const std::string& loadString, const NewResource::KeepLevel& keepLevel, const TextureData::Pointer& data)
+    : NewResource::Pointer(loadString, keepLevel) , pointer(data)
 {}
 
Index: branches/new_class_id/src/lib/graphics/importer/resource_texture.h
===================================================================
--- branches/new_class_id/src/lib/graphics/importer/resource_texture.h	(revision 9787)
+++ branches/new_class_id/src/lib/graphics/importer/resource_texture.h	(revision 9788)
@@ -12,5 +12,5 @@
 
 
-class ResourceTexture : public Texture, public Resource
+class ResourceTexture : public Texture, public NewResource
 {
 public:
@@ -19,8 +19,8 @@
 
 private:
-class TextureResourcePointer : public Resource::Pointer
+class TextureResourcePointer : public NewResource::Pointer
   {
   public:
-    TextureResourcePointer(const std::string& loadString, const Resource::KeepLevel& keepLevel, const TextureData::Pointer& data);
+    TextureResourcePointer(const std::string& loadString, const NewResource::KeepLevel& keepLevel, const TextureData::Pointer& data);
     inline const TextureData::Pointer& ptr() const { return pointer; }
   private:
@@ -29,5 +29,5 @@
 
 private:
-  static Resource::Type type;
+  static NewResource::Type type;
 };
 
Index: branches/new_class_id/src/lib/util/loading/resource.cc
===================================================================
--- branches/new_class_id/src/lib/util/loading/resource.cc	(revision 9787)
+++ branches/new_class_id/src/lib/util/loading/resource.cc	(revision 9788)
@@ -19,12 +19,12 @@
 #include "filesys/file.h"
 
-ObjectListDefinition(Resource);
+ObjectListDefinition(NewResource);
 
 
-std::vector<Resource::Type*>    Resource::_resourceTypes;
+std::vector<NewResource::Type*>    NewResource::_resourceTypes;
 
 //! GLOBALS
-Directory Resource::_mainGlobalPath;
-std::vector<Directory>        Resource::_globalPaths;
+Directory NewResource::_mainGlobalPath;
+std::vector<Directory>        NewResource::_globalPaths;
 
 
@@ -32,13 +32,13 @@
  * standard constructor
 */
-Resource::Resource (Resource::Type* type)
+NewResource::NewResource (NewResource::Type* type)
     : _pointer(NULL), _type(type)
 {
-  this->registerObject(this, Resource::_objectList);
+  this->registerObject(this, NewResource::_objectList);
 
   if(this->_type->id() == -1)
   {
-    Resource::_resourceTypes.push_back(this->_type);
-    this->_type->setID(Resource::_resourceTypes.size()-1);
+    NewResource::_resourceTypes.push_back(this->_type);
+    this->_type->setID(NewResource::_resourceTypes.size()-1);
   }
 
@@ -48,5 +48,5 @@
  * standard deconstructor
  */
-Resource::~Resource ()
+NewResource::~NewResource ()
 {
   // delete what has to be deleted here
@@ -54,10 +54,10 @@
 
 
-std::string Resource::locateFile(const std::string& fileName)
+std::string NewResource::locateFile(const std::string& fileName)
 {
   if (File(fileName).exists())
     return fileName;
-  else if ((Resource::_mainGlobalPath+File(fileName)) . exists() )
-    return (Resource::_mainGlobalPath + File(fileName)).name();
+  else if ((NewResource::_mainGlobalPath+File(fileName)) . exists() )
+    return (NewResource::_mainGlobalPath + File(fileName)).name();
 
   return std::string("/home/bensch/svn/orxonox/data/") + fileName;
@@ -66,7 +66,7 @@
 
 
-Resource::Pointer* Resource::acquireResource(const std::string& loadString)
+NewResource::Pointer* NewResource::acquireResource(const std::string& loadString)
 {
-  //const Resource::Type* const type = Resource::_resourceTypes[this->_type->id()];
+  //const NewResource::Type* const type = NewResource::_resourceTypes[this->_type->id()];
 
   for (unsigned int i = 0; i < _type->storedResources().size(); ++i)
@@ -79,20 +79,20 @@
 }
 
-void Resource::setMainGlobalPath(const Directory& directory)
+void NewResource::setMainGlobalPath(const Directory& directory)
 {
-  Resource::_mainGlobalPath = directory;
-  Resource::_mainGlobalPath.open();
+  NewResource::_mainGlobalPath = directory;
+  NewResource::_mainGlobalPath.open();
 }
 
-void Resource::addGlobalPath(const Directory& directory)
+void NewResource::addGlobalPath(const Directory& directory)
 {
-  std::vector<Directory>::const_iterator it = std::find(Resource::_globalPaths.begin(), Resource::_globalPaths.end(), directory);
-  if (it == Resource::_globalPaths.end())
-    Resource::_globalPaths.push_back(directory);
+  std::vector<Directory>::const_iterator it = std::find(NewResource::_globalPaths.begin(), NewResource::_globalPaths.end(), directory);
+  if (it == NewResource::_globalPaths.end())
+    NewResource::_globalPaths.push_back(directory);
 }
 
 
 
-void Resource::addResource(Resource::Pointer* pointer)
+void NewResource::addResource(NewResource::Pointer* pointer)
 {
   this->_type->addResource(pointer);
@@ -108,5 +108,5 @@
 
 
-void Resource::KeepLevel::setKeepLevelName(unsigned int level, const std::string& name)
+void NewResource::KeepLevel::setKeepLevelName(unsigned int level, const std::string& name)
 {
   if (_keepLevelName.size() <= level)
@@ -117,5 +117,5 @@
 
 
-void Resource::Type::addResource(Resource::Pointer* resource)
+void NewResource::Type::addResource(NewResource::Pointer* resource)
 {
   this->_storedResources.push_back(resource);
@@ -124,10 +124,10 @@
 
 
-Resource::Pointer::Pointer(const std::string& loadString, const Resource::KeepLevel& keeplevel)
+NewResource::Pointer::Pointer(const std::string& loadString, const NewResource::KeepLevel& keeplevel)
   : _loadString(loadString), _keepLevel(keeplevel)
 {}
 
 
-void Resource::Type::setID(int id)
+void NewResource::Type::setID(int id)
 {
   this->_id = id;
Index: branches/new_class_id/src/lib/util/loading/resource.h
===================================================================
--- branches/new_class_id/src/lib/util/loading/resource.h	(revision 9787)
+++ branches/new_class_id/src/lib/util/loading/resource.h	(revision 9788)
@@ -1,5 +1,5 @@
 /*!
  * @file resource.h
  * @brief Definition of a Resource.
 */
 
@@ -15,11 +15,11 @@
 #include "filesys/directory.h"
 
 //! A Resource is an Object, that can be loaded from Disk
 /**
  *
  */
-class Resource : virtual public BaseObject
+class NewResource : virtual public BaseObject
 {
-  ObjectListDeclaration(Resource);
+  ObjectListDeclaration(NewResource);
 public:
   class KeepLevel
@@ -35,11 +35,11 @@
   {
   public:
-    Pointer(const std::string& loadString, const Resource::KeepLevel& keeplevel);
+    Pointer(const std::string& loadString, const NewResource::KeepLevel& keeplevel);
     const std::string& loadString() const { return _loadString; };
-    const Resource::KeepLevel& keepLevel() const { return _keepLevel; };
+    const NewResource::KeepLevel& keepLevel() const { return _keepLevel; };
 
   private:
     std::string              _loadString;             //!< An identifier, to match when loading a File.
-    Resource::KeepLevel      _keepLevel;              //!< The Priority of this resource. (can only be increased, so none else will delete this)
+    NewResource::KeepLevel      _keepLevel;              //!< The Priority of this resource. (can only be increased, so none else will delete this)
   };
 
@@ -60,8 +60,8 @@
     const std::vector<std::string>& resourcePaths() const { return _resourcePaths; };
     const std::vector<std::string>& resourceSubPaths() const { return _resourceSubPaths; };
-    const std::vector<Resource::Pointer*>& storedResources() const { return _storedResources; };
+    const std::vector<NewResource::Pointer*>& storedResources() const { return _storedResources; };
 
     void setID(int id);
-    void addResource(Resource::Pointer* resource);
+    void addResource(NewResource::Pointer* resource);
 
   private:
@@ -72,11 +72,11 @@
     std::vector<std::string>        _fileExtensions;
 
-    std::vector<Resource::Pointer*> _storedResources;
+    std::vector<NewResource::Pointer*> _storedResources;
   };
 
 
 public:
-  Resource(Resource::Type* type);
-  virtual ~Resource();
+  NewResource(NewResource::Type* type);
+  virtual ~NewResource();
 
   virtual bool reload() { return false; };
@@ -92,13 +92,13 @@
 
 protected:
-  Resource::Pointer* acquireResource(const std::string& loadString);
-  void addResource(Resource::Pointer* pointer);
+  NewResource::Pointer* acquireResource(const std::string& loadString);
+  void addResource(NewResource::Pointer* pointer);
 
 private:
-  Resource::Pointer*       _pointer;                         //!< Virtual Pointer to the ResourceData.
-  Resource::Type*          _type;                            //!< Type of the Resource.
+  NewResource::Pointer*       _pointer;                         //!< Virtual Pointer to the ResourceData.
+  NewResource::Type*          _type;                            //!< Type of the NewResource.
 
 
-  static std::vector<Resource::Type*>    _resourceTypes;
+  static std::vector<NewResource::Type*>    _resourceTypes;
 
   //! GLOBALS
@@ -1,5 +1,5 @@
 /*!
  * @file resource.h
- * @brief Definition of a Resource.
+ * @brief Definition of a NewResource.
 */
 
@@ -15,11 +15,11 @@
 #include "filesys/directory.h"
 
-//! A Resource is an Object, that can be loaded from Disk
+//! A NewResource is an Object, that can be loaded from Disk
 /**
  *
